crabnet package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crabnet.data
   crabnet.utils

Submodules
----------

crabnet.crabnet\_ module
------------------------

.. automodule:: crabnet.crabnet_
   :members:
   :undoc-members:
   :show-inheritance:

crabnet.kingcrab module
-----------------------

.. automodule:: crabnet.kingcrab
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: crabnet
   :members:
   :undoc-members:
   :show-inheritance:
